@@ -1,58 +1,13 @@
 package Business::ES::NIF;
 
-=head1 NAME
+# ABSTRACT: Validate Spanish NIF, NIE and CIF numbers
 
- Business::ES::NIF - Validate Spanish NIF, NIE and CIF numbers
 
-=cut
-
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 use strict;
 use warnings;
 
-=head1 SYNOPSIS
-
-    use Business::ES::NIF;
-
-    my $NIF = Business::ES::NIF->new( nif => '01234567L' , vies => 0);
-
-    $NIF->set('B01234567');
-    $NIF->set('B01234567',1); <= Check VIES ( Business::Tax::VAT::Validation )
-
- Dump:
-
-    bless( {
-           'status' => 1,
-           'nif' => '01234567L',
-           'vies' => 0,
-           'extra' => 'NIF',
-           'type' => 'NIF',
-           }, 'NIF' );
-
-    bless( {
-           'status' => 0,
-           'nif' => 'B01234567',
-           'vies' => 1,
-           'vies_check' => 0,
-           'extra' => 'Sociedad Limitada - S.L',
-           'type' => 'CIF',
-           'vies_error' => 'Invalid VAT Number (false)'
-           }, 'NIF' );
-
-=head1 DESCRIPTION
-
-Validate a Spanish NIF / CIF / NIE
-
-Referencias: http://es.wikipedia.org/wiki/Numero_de_identificacion_fiscal  
-
-Se puede activar la comprobacion sobre el VIES ( Business::Tax::VAT::Validation )
-
-=head1 EXPORT
-
-=head1 SUBROUTINES/METHODS
-
-=cut 
 
 use constant {
 	      NIF_LETRAS => 'TRWAGMYFPDXBNJZSQVHLCKE',
@@ -64,211 +19,134 @@ use constant {
 	      RE_NIE     => qr/^([XYZ])([0-9]{7})([A-Z])$/
 	     };
 
-my %PROVINCIA_CODES = (
-		       '00' => 'No Residente',
-		       '01' => 'Álava',
-		       '02' => 'Albacete', 
-		       '03' => 'Alicante',
-		       '04' => 'Almería',
-		       '05' => 'Ávila',
-		       '06' => 'Badajoz',
-		       '07' => 'Islas Baleares',
-		       '08' => 'Barcelona',
-		       '09' => 'Burgos',
-		       '10' => 'Cáceres',
-		       '11' => 'Cádiz',
-		       '12' => 'Castellón',
-		       '13' => 'Ciudad Real',
-		       '14' => 'Córdoba',
-		       '15' => 'La Coruña',
-		       '16' => 'Cuenca',
-		       '17' => 'Gerona',
-		       '18' => 'Granada',
-		       '19' => 'Guadalajara',
-		       '20' => 'Guipúzcoa',
-		       '21' => 'Huelva',
-		       '22' => 'Huesca',
-		       '23' => 'Jaén',
-		       '24' => 'León',
-		       '25' => 'Lérida',
-		       '26' => 'La Rioja',
-		       '27' => 'Lugo',
-		       '28' => 'Madrid',
-		       '29' => 'Málaga',
-		       '30' => 'Murcia',
-		       '31' => 'Navarra',
-		       '32' => 'Orense',
-		       '33' => 'Asturias',
-		       '34' => 'Palencia',
-		       '35' => 'Las Palmas',
-		       '36' => 'Pontevedra',
-		       '37' => 'Salamanca',
-		       '38' => 'Santa Cruz de Tenerife',
-		       '39' => 'Cantabria',
-		       '40' => 'Segovia',
-		       '41' => 'Sevilla',
-		       '42' => 'Soria',
-		       '43' => 'Tarragona',
-		       '44' => 'Teruel',
-		       '45' => 'Toledo',
-		       '46' => 'Valencia',
-		       '47' => 'Valladolid',
-		       '48' => 'Vizcaya',
-		       '49' => 'Zamora',
-		       '50' => 'Zaragoza',
-		       '51' => 'Ceuta',
-		       '52' => 'Melilla',
-		       '53' => 'Alicante',         
-		       '54' => 'Alicante',         
-		       '55' => 'Gerona',           
-		       '56' => 'Córdoba',          
-		       '57' => 'Islas Baleares',   
-		       '58' => 'Barcelona',        
-		       '59' => 'Barcelona',
-		       '60' => 'Barcelona',
-		       '61' => 'Barcelona',
-		       '62' => 'Barcelona',
-		       '63' => 'Barcelona',
-		       '64' => 'Barcelona',
-		       '65' => 'Barcelona',
-		       '66' => 'Barcelona',
-		       '67' => 'Gerona',           
-		       '68' => 'Barcelona',        
-		       '70' => 'La Coruña',        
-		       '71' => 'Guipúzcoa',        
-		       '72' => 'Cádiz',            
-		       '73' => 'Murcia',           
-		       '74' => 'Asturias',         
-		       '75' => 'Las Palmas',       
-		       '76' => 'Santa Cruz de Tenerife',
-		       '77' => 'Tarragona',        
-		       '78' => 'Madrid',           
-		       '79' => 'Madrid',
-		       '80' => 'Madrid',
-		       '81' => 'Madrid',
-		       '82' => 'Madrid',
-		       '83' => 'Madrid',
-		       '84' => 'Madrid',
-		       '85' => 'Madrid',
-		       '86' => 'Madrid',
-		       '87' => 'Madrid',
-		       '88' => 'Madrid',
-		       '90' => 'Sevilla',          
-		       '91' => 'Sevilla',          
-		       '92' => 'Málaga',           
-		       '93' => 'Málaga',           
-		       '94' => 'Pontevedra',       
-		       '95' => 'Vizcaya',          
-		       '96' => 'Valencia',         
-		       '97' => 'Valencia',
-		       '98' => 'Valencia',
-		       '99' => 'Zaragoza',
-		      );
-
-my $Types = {
-	     CIF => {
-                     re  => RE_CIF,
-                     val => sub {
-		       $_[0] =~ RE_CIF or return 0;
-                       return _validate_cif($1, $2, $3);
-                     },
-                     extra => sub {
-                       return {
-			       'A' => 'Sociedad Anonima - S.A',
-			       'B' => 'Sociedad Limitada - S.L',
-			       'C' => 'Sociedad Colectiva - S.C',
-			       'D' => 'Sociedades comanditarias',
-			       'E' => 'Comunidad de bienes y herencias',
-			       'F' => 'Sociedades cooperativas',
-			       'G' => 'Asociaciones',
-			       'H' => 'Comunidaddes de propietarios',
-			       'J' => 'Sociedades civiles',
-			       'P' => 'Corporaciones locales',
-			       'Q' => 'Organismos publicos',
-			       'N' => 'Entidades extranjeras',
-			       'R' => 'Congregaciones e instituciones religiosas',
-			       'U' => 'Uniones temporales de epresas',
-			       'V' => 'Otros tipos de sociedades',
-			       'W' => 'Establecimientos permanentes de entidades no residentes en España',
-			      }->{ substr(shift, 0, 1) };
-                     }
-                    },
-	     CIFe => {
-		      re  => RE_CIFe,
-		      val => sub {
-			$_[0] =~ RE_CIFe or return 0;
-			return _validate_cif($1,$2,$3);
-		      },
-		      extra => sub {
-			return {
-				'S' => 'Órganos de la Administración del Estado',
-				'Q' => 'Organismos autónomos o instituciones religiosas',
-				'P' => 'Corporaciones locales',
-				'K' => 'Formato antiguo (DNI sin letra de control)',
-			       }->{ substr(shift, 0, 1) };
-		      }
-		     },
-	     NIF => {
-                     re    => RE_NIF,
-		     extra => sub { return 'NIF'; },
-                     val   => sub { return _validate_nif(shift); }
-                    },
-	     NIFe => {
-		      re    => RE_NIFe,
-		      extra => sub { return 'NIF Especial (KLM)'; },
-		      val   => sub {
-			shift =~ /^[KLM]([0-9]{7})([A-Z])$/ or return 0;
-			return substr(NIF_LETRAS, $1 % 23, 1) eq $2 ? 1 : 0;
-		      }
-		     },
-	     NIE => {
-		     re    => RE_NIE,
-		     extra => sub { return 'NIE'; },
-		     val   => sub { return _validate_nie(shift); }
-		    }
-	    };
-
-=head2 type
-
-Devuelve el tipo (NIF, NIE, CIF, CIFe, NIFe).
-
-    my $tipo = $obj->type;
-
-=head2 extra
-
-Devuelve una descripcion extra del tipo, por ejemplo:
-
-"Sociedad Anonima - S.A", "NIE", "NIF Especial (KLM)", etc.
-
-    my $desc = $obj->extra;
-
-=head2 error
-
-Devuelve el mensaje de error (si existe) cuando el NIF no es valido.
-
-    warn $obj->error unless $obj->is_valid;
-
-=cut
 
 sub type  { return shift->{type};  }
 sub extra { return shift->{extra}; }
 sub error { return shift->{error}; }
 
-sub _cif_provincia {
-  my $cif = shift;
 
-  return unless defined $cif;
-
-  my $provincia = substr($cif, 1, 2);
+sub is_nie  { return shift->{type} eq 'NIE'  }
+sub is_nif  { return shift->{type} eq 'NIF'  }
+sub is_nife { return shift->{type} eq 'NIFe' }
+sub is_cif  { return shift->{type} eq 'CIF'  }
+sub is_cife { return shift->{type} eq 'CIFe' }
 
+sub _provincia {
+  my $provincia = shift;
+  
+  my %PROVINCIAS = (
+		    '00' => 'No Residente',
+		    '01' => 'Álava',
+		    '02' => 'Albacete', 
+		    '03' => 'Alicante',
+		    '04' => 'Almería',
+		    '05' => 'Ávila',
+		    '06' => 'Badajoz',
+		    '07' => 'Islas Baleares',
+		    '08' => 'Barcelona',
+		    '09' => 'Burgos',
+		    '10' => 'Cáceres',
+		    '11' => 'Cádiz',
+		    '12' => 'Castellón',
+		    '13' => 'Ciudad Real',
+		    '14' => 'Córdoba',
+		    '15' => 'La Coruña',
+		    '16' => 'Cuenca',
+		    '17' => 'Gerona',
+		    '18' => 'Granada',
+		    '19' => 'Guadalajara',
+		    '20' => 'Guipúzcoa',
+		    '21' => 'Huelva',
+		    '22' => 'Huesca',
+		    '23' => 'Jaén',
+		    '24' => 'León',
+		    '25' => 'Lérida',
+		    '26' => 'La Rioja',
+		    '27' => 'Lugo',
+		    '28' => 'Madrid',
+		    '29' => 'Málaga',
+		    '30' => 'Murcia',
+		    '31' => 'Navarra',
+		    '32' => 'Orense',
+		    '33' => 'Asturias',
+		    '34' => 'Palencia',
+		    '35' => 'Las Palmas',
+		    '36' => 'Pontevedra',
+		    '37' => 'Salamanca',
+		    '38' => 'Santa Cruz de Tenerife',
+		    '39' => 'Cantabria',
+		    '40' => 'Segovia',
+		    '41' => 'Sevilla',
+		    '42' => 'Soria',
+		    '43' => 'Tarragona',
+		    '44' => 'Teruel',
+		    '45' => 'Toledo',
+		    '46' => 'Valencia',
+		    '47' => 'Valladolid',
+		    '48' => 'Vizcaya',
+		    '49' => 'Zamora',
+		    '50' => 'Zaragoza',
+		    '51' => 'Ceuta',
+		    '52' => 'Melilla',
+		    '53' => 'Alicante',         
+		    '54' => 'Alicante',         
+		    '55' => 'Gerona',           
+		    '56' => 'Córdoba',          
+		    '57' => 'Islas Baleares',   
+		    '58' => 'Barcelona',        
+		    '59' => 'Barcelona',
+		    '60' => 'Barcelona',
+		    '61' => 'Barcelona',
+		    '62' => 'Barcelona',
+		    '63' => 'Barcelona',
+		    '64' => 'Barcelona',
+		    '65' => 'Barcelona',
+		    '66' => 'Barcelona',
+		    '67' => 'Gerona',           
+		    '68' => 'Barcelona',        
+		    '70' => 'La Coruña',        
+		    '71' => 'Guipúzcoa',        
+		    '72' => 'Cádiz',            
+		    '73' => 'Murcia',           
+		    '74' => 'Asturias',         
+		    '75' => 'Las Palmas',       
+		    '76' => 'Santa Cruz de Tenerife',
+		    '77' => 'Tarragona',        
+		    '78' => 'Madrid',           
+		    '79' => 'Madrid',
+		    '80' => 'Madrid',
+		    '81' => 'Madrid',
+		    '82' => 'Madrid',
+		    '83' => 'Madrid',
+		    '84' => 'Madrid',
+		    '85' => 'Madrid',
+		    '86' => 'Madrid',
+		    '87' => 'Madrid',
+		    '88' => 'Madrid',
+		    '90' => 'Sevilla',          
+		    '91' => 'Sevilla',          
+		    '92' => 'Málaga',           
+		    '93' => 'Málaga',           
+		    '94' => 'Pontevedra',       
+		    '95' => 'Vizcaya',          
+		    '96' => 'Valencia',         
+		    '97' => 'Valencia',
+		    '98' => 'Valencia',
+		    '99' => 'Zaragoza',
+		   );
+  
   return unless $provincia =~ /^[0-9]{2}$/;
-
-  return $PROVINCIA_CODES{$provincia};
+  
+  return $PROVINCIAS{$provincia};
 }
 
-sub _validate_cif {
-  my ($sociedad, $inscripcion, $control) = @_;
 
+sub _check_cif {
+  my $self = shift;
+  my $sociedad = shift;
+  my $inscripcion = shift;
+  my $control = shift;
+  
   my @n = split //, $inscripcion;
   my $pares = $n[1] + $n[3] + $n[5];
   my $nones;
@@ -288,17 +166,108 @@ sub _validate_cif {
       return 0 if $c != $control and $l ne uc($control);
     }
   }
+    
+  return 1;
+}
+
+sub _validate_cif {
+  my $self = shift;
+  my $cif  = shift;
+
+  $self->{type} = 'CIF';
   
+  $cif =~ RE_CIF;
+
+  my $status = $self->_check_cif($1, $2, $3);
+
+  $self->{provincia} = _provincia(substr($cif,1,2));
+  
+  return 0 unless $status;
+  
+  $self->{extra} = {
+                    'A' => 'Sociedad Anonima - S.A',
+                    'B' => 'Sociedad Limitada - S.L',
+                    'C' => 'Sociedad Colectiva - S.C',
+                    'D' => 'Sociedades comanditarias',
+                    'E' => 'Comunidad de bienes y herencias',
+                    'F' => 'Sociedades cooperativas',
+                    'G' => 'Asociaciones',
+                    'H' => 'Comunidaddes de propietarios',
+                    'J' => 'Sociedades civiles',
+                    'P' => 'Corporaciones locales',
+                    'Q' => 'Organismos publicos',
+                    'N' => 'Entidades extranjeras',
+                    'R' => 'Congregaciones e instituciones religiosas',
+                    'U' => 'Uniones temporales de epresas',
+                    'V' => 'Otros tipos de sociedades',
+                    'W' => 'Establecimientos permanentes de entidades no residentes en España',
+                   }->{ substr($cif, 0, 1) };
+
+  return 1;
+}
+
+sub _validate_cife {
+  my $self = shift;
+  my $cif  = shift;
+
+  $self->{type} = 'CIFe';
+  
+  $cif =~ RE_CIFe;
+
+  my $status = $self->_check_cif($1,$2,$3);
+  
+  return 0 unless $status;
+  
+  $self->{extra} = {
+		    'S' => 'Órganos de la Administración del Estado',
+		    'Q' => 'Organismos autónomos o instituciones religiosas',
+		    'P' => 'Corporaciones locales',
+		    'K' => 'Formato antiguo (DNI sin letra de control)',
+		   }->{ substr($cif, 0, 1) };
+
   return 1;
 }
 
 sub _validate_nif {
-  shift =~ RE_NIF;
-  return substr( NIF_LETRAS , $1 % 23, 1) eq $2 ? 1 : 0;
+  my $self = shift;
+  my $nif  = shift;
+
+  $self->{type} = 'NIF';
+  
+  $nif =~ RE_NIF;
+
+  my $status = substr( NIF_LETRAS , $1 % 23, 1) eq $2 ? 1 : 0;
+
+  return 0 unless $status;
+
+  $self->{extra} = 'NIF';
+  
+  return 1;
+}
+sub _validate_nife {
+  my $self = shift;
+  my $nif  = shift;
+
+  $self->{type} = 'NIFe';
+  
+  $nif =~ /^[KLM]([0-9]{7})([A-Z])$/;
+
+  my $status = substr(NIF_LETRAS, $1 % 23, 1) eq $2 ? 1 : 0;
+
+  return 0 unless $status;
+
+  $self->{extra} = 'NIF Especial (KLM)';
+  
+  return 1;
 }
 
 sub _validate_nie {
-  shift =~ RE_NIE;
+  my $self = shift;
+  my $nie  = shift;
+
+  $self->{type} = 'NIE';
+  
+  $nie =~ RE_NIE;
 
   my ($NIE,$NIF,$DC) = ($1,$2,$3);
                        
@@ -308,21 +277,24 @@ sub _validate_nie {
     $NIF = '2'.$NIF if /Z/;
   }
   
-  return substr( NIF_LETRAS , $NIF % 23, 1) eq $DC ? 1 : 0;
+  my $status = substr( NIF_LETRAS , $NIF % 23, 1) eq $DC ? 1 : 0;
+
+  return 0 unless $status;
+
+  $self->{extra} = 'NIE';
+
+  return 1;
 }
 
-=head2 new
-
-    new method
-
-=cut
 
 sub new {
   my ($class, %args) = @_;
 
   my $self = {
-	      nif    => '',
+	      nif    => undef,
+	      extra  => undef,
 	      status => 0,
+	      type   => undef,
 	      vies   => $args{vies} // 0
 	     };
   
@@ -333,13 +305,6 @@ sub new {
   return $self;
 }
 
-=head2 set
-
-    Set NIF
-
-    $vies = 1 | 0
-
-=cut
 
 sub set {
   my $self = shift;
@@ -354,53 +319,36 @@ sub set {
     return;
   }
 
-  $self->{nif} = uc($nif =~ tr/-. //dr);
+  $nif =~ tr/-. //d;
+  $self->{nif} = uc($nif);
 
-  delete $self->{nif_check} if $self->{nif_check};
-
-  $self->check();
+  $self->check;
 }
 
-=head2 is_valid
-
-=cut
 
 sub is_valid { return shift->{status} ? 1 : 0; }
 
-=head2 check
-
-=cut
 
 sub check {
   my $self = shift;
-  
-  for my $type (keys %{ $Types }) {
-    if ( $self->{nif} =~ $Types->{$type}->{re} ) {
-      
-      $self->{type}   = $type;
-      $self->{status} = $Types->{$type}->{val}->($self->{nif});
-      $self->{extra}  = $Types->{$type}->{extra}->($self->{nif});
-      
-      $self->{nif_check} = $Types->{NIF}->{val}->($self->{nif},1)
-	if $self->{status} == 0 && $self->{type} eq 'NIF';
+  my $nif  = $self->{nif};
 
-      $self->{provincia} = _cif_provincia($self->{nif}) if $self->{type} eq 'CIF';
+  if    ($nif =~ RE_NIF)  { $self->{status} = $self->_validate_nif($nif);  }
+  elsif ($nif =~ RE_CIF)  { $self->{status} = $self->_validate_cif($nif);  }
+  elsif ($nif =~ RE_NIE)  { $self->{status} = $self->_validate_nie($nif);  }
+  elsif ($nif =~ RE_NIFe) { $self->{status} = $self->_validate_nife($nif); }
+  elsif ($nif =~ RE_CIFe) { $self->{status} = $self->_validate_cife($nif); }
 
-      $self->vies() if $self->{vies};
-
-      return;
-    }
+  if ( $self->{status} ) {
+    $self->vies() if $self->{vies};
+    return;
   }
   
   $self->{error} = "Error formato de NIF/CIF/NIE";
-  $self->{type}  = 'ERROR';
+
+  return;
 }
 
-=head2 vies
-
-Valida el NIF contra el sistema europeo VIES. Devuelve 1 si es correct, 0 si no lo es.
-
-=cut
 
 sub vies {
   my $self = shift;
@@ -441,6 +389,136 @@ sub vies {
   return $self->{vies_check} // 0;
 }
 
+
+1;
+
+__END__
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Business::ES::NIF - Validate Spanish NIF, NIE and CIF numbers
+
+=head1 VERSION
+
+version 0.11
+
+=head1 SYNOPSIS
+
+    use Business::ES::NIF;
+
+    my $NIF = Business::ES::NIF->new( nif => '01234567L' , vies => 0);
+
+    $NIF->set('B01234567');
+    $NIF->set('B01234567',1); <= Check VIES ( Business::Tax::VAT::Validation )
+
+ Dump:
+
+    bless( {
+           'status' => 1,
+           'nif' => '01234567L',
+           'vies' => 0,
+           'extra' => 'NIF',
+           'type' => 'NIF',
+           }, 'NIF' );
+
+    bless( {
+           'status' => 0,
+           'nif' => 'B01234567',
+           'vies' => 1,
+           'vies_check' => 0,
+           'extra' => 'Sociedad Limitada - S.L',
+           'type' => 'CIF',
+           'vies_error' => 'Invalid VAT Number (false)'
+           }, 'NIF' );
+
+=head1 DESCRIPTION
+
+Validate a Spanish NIF / CIF / NIE
+
+Referencias: http://es.wikipedia.org/wiki/Numero_de_identificacion_fiscal  
+
+Se puede activar la comprobacion sobre el VIES ( Business::Tax::VAT::Validation )
+
+=head1 NAME
+
+ Business::ES::NIF - Validate Spanish NIF, NIE and CIF numbers
+
+=head1 EXPORT
+
+=head1 SUBROUTINES/METHODS
+
+=head2 type
+
+Devuelve el tipo (NIF, NIE, CIF, CIFe, NIFe)
+
+    my $tipo = $obj->type;
+
+=head2 extra
+
+Devuelve una descripcion extra del tipo, por ejemplo:
+
+"Sociedad Anonima - S.A", "NIE", "NIF Especial (KLM)" ...
+
+    my $desc = $obj->extra;
+
+=head2 error
+
+Devuelve el mensaje de error (si existe) cuando el NIF no es valido
+
+    warn $obj->error unless $obj->is_valid;
+
+=head2 is_nif
+
+  $obj->is_nif
+
+Devuelve verdadero si el tipo detectado es un NIF (Número de Identificación Fiscal para personas físicas españolas).
+
+=head2 is_nife
+
+  $obj->is_nife
+
+Devuelve verdadero si el tipo detectado es un NIF especial (K, L o M), utilizado por menores de edad, residentes o asimilados.
+
+=head2 is_nie
+
+  $obj->is_nie
+
+Devuelve verdadero si el tipo detectado es un NIE (Número de Identificación de Extranjeros).
+
+=head2 is_cif
+
+  $obj->is_cif
+
+Devuelve verdadero si el tipo detectado es un CIF (Código de Identificación Fiscal para entidades jurídicas).
+
+=head2 is_cife
+
+  $obj->is_cife
+
+Devuelve verdadero si el tipo detectado es un CIF especial (entidades del estado, corporaciones, etc.).
+
+=head2 new
+
+    new method
+
+=head2 set
+
+    Set NIF
+
+    $vies = 1 | 0
+
+=head2 is_valid
+
+=head2 check
+
+=head2 vies
+
+Valida el NIF contra el sistema europeo VIES. Devuelve 1 si es correcto, 0 si no lo es.
+
 =head1 AUTHOR
 
 Harun Delgado, C<< <hdp at djmania.es> >> L<https://djmania.es>
@@ -451,7 +529,6 @@ Please report any bugs or feature requests to C<bug-business-es-nif at rt.cpan.o
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Business-ES-NIF>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
@@ -466,10 +543,6 @@ You can also look for information at:
 
 L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Business-ES-NIF>
 
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Business-ES-NIF>
-
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Business-ES-NIF>
@@ -480,10 +553,8 @@ L<http://search.cpan.org/dist/Business-ES-NIF/>
 
 =back
 
-
 =head1 ACKNOWLEDGEMENTS
 
-
 =head1 LICENSE AND COPYRIGHT
 
 This program is free software; you can redistribute it and/or modify it
@@ -522,7 +593,15 @@ CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
 CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
 EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
+=head1 AUTHOR
+
+H <>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2025 by H.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
